@@ -27,18 +27,17 @@ extern crate alloc;
 
 pub use async_trait::async_trait;
 
-pub extern crate hashbrown;
-
-#[allow(unused_imports)]
-#[macro_use]
-pub extern crate hex;
-
 #[allow(unused_imports)]
 #[macro_use]
 /// Re-export of the `async_trait` macro crate.
 pub extern crate async_trait;
+
 /// Mark an Ockam Worker implementation.
+#[doc(inline)]
 pub use async_trait::async_trait as worker;
+/// Mark an Ockam Processor implementation.
+#[doc(inline)]
+pub use async_trait::async_trait as processor;
 
 extern crate ockam_macros;
 pub use ockam_macros::{AsyncTryClone, Message};
