@@ -8,7 +8,7 @@ pub trait AsymmetricVault {
     /// Compute Elliptic-Curve Diffie-Hellman using this secret key
     /// and the specified uncompressed public key.
     async fn ec_diffie_hellman(
-        &mut self,
+        &self,
         context: &Secret,
         peer_public_key: &PublicKey,
     ) -> Result<Secret>;
