@@ -3,6 +3,12 @@
 //! This module contains the core types and traits of the Ockam vault and is intended
 //! for use by other crates that either provide implementations for those traits,
 //! or use traits and types as an abstract dependency.
+//!
+//! # Examples
+//!
+//! See the [`ockam_vault`] crate for usage examples.
+//!
+//! [`ockam_vault`]: https://docs.rs/ockam_vault/latest
 
 mod asymmetric_vault;
 mod hasher;
@@ -14,6 +20,8 @@ mod symmetric_vault;
 mod types;
 mod verifier;
 
+pub mod test_support;
+
 pub use asymmetric_vault::*;
 pub use hasher::*;
 pub use key_id_vault::*;
