@@ -11,19 +11,15 @@ use crate::{async_trait, compat::boxed::Box};
 #[async_trait]
 pub trait SecretVault {
     /// Generate a fresh secret with the given attributes.
-    async fn secret_generate(&mut self, attributes: SecretAttributes) -> Result<Secret>;
+    async fn secret_generate(&self, attributes: SecretAttributes) -> Result<Secret>;
     /// Import a secret with the given attributes from binary form into the vault.
-    async fn secret_import(
-        &mut self,
-        secret: &[u8],
-        attributes: SecretAttributes,
-    ) -> Result<Secret>;
+    async fn secret_import(&self, secret: &[u8], attributes: SecretAttributes) -> Result<Secret>;
     /// Export a secret key to the binary form represented as [`SecretKey`].
-    async fn secret_export(&mut self, context: &Secret) -> Result<SecretKey>;
+    async fn secret_export(&self, context: &Secret) -> Result<SecretKey>;
     /// Return the attributes for a secret.
-    async fn secret_attributes_get(&mut self, context: &Secret) -> Result<SecretAttributes>;
+    async fn secret_attributes_get(&self, context: &Secret) -> Result<SecretAttributes>;
     /// Return the associated public key given the secret key.
-    async fn secret_public_key_get(&mut self, context: &Secret) -> Result<PublicKey>;
+    async fn secret_public_key_get(&self, context: &Secret) -> Result<PublicKey>;
     /// Remove a secret from the vault.
-    async fn secret_destroy(&mut self, context: Secret) -> Result<()>;
+    async fn secret_destroy(&self, context: Secret) -> Result<()>;
 }
