@@ -6,5 +6,5 @@ use crate::{async_trait, compat::boxed::Box};
 #[async_trait]
 pub trait Signer {
     /// Generate a `Signature` for the given data using the given `Secret` key.
-    async fn sign(&mut self, secret_key: &Secret, data: &[u8]) -> Result<Signature>;
+    async fn sign(&self, secret_key: &Secret, data: &[u8]) -> Result<Signature>;
 }
